@@ -2,9 +2,9 @@ package Acme::MITHALDU::XSGrabBag;
 use strictures;
 use Exporter 'import';
 use Acme::MITHALDU::XSGrabBag::Inline ();
-use Inline::C                         ();
+use Inline::C 0.74 ();
 
-our $VERSION = '1.161290'; # VERSION
+our $VERSION = '1.161310'; # VERSION
 
 # ABSTRACT: a bunch of XS math functions i'm not sure where to shove yet
 
@@ -96,7 +96,7 @@ Acme::MITHALDU::XSGrabBag - a bunch of XS math functions i'm not sure where to s
 
 =head1 VERSION
 
-version 1.161290
+version 1.161310
 
 =head1 DESCRIPTION
 
